"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_sdk_1 = require("lisk-sdk");
const path_1 = __importDefault(require("path"));
const build_1 = require("./build");
const git_1 = require("./git");
const packageJSON = require('../../package.json');
let lastCommitId;
let buildVersion;
try {
    lastCommitId = git_1.getLastCommitId();
}
catch (err) {
}
try {
    buildVersion = build_1.getBuildVersion();
}
catch (err) {
}
const appSchema = {
    type: 'object',
    properties: {
        NETWORK: {
            type: 'string',
            description: 'lisk network [devnet|betanet|mainnet|testnet]. Defaults to "devnet"',
            enum: ['devnet', 'alphanet', 'betanet', 'testnet', 'mainnet'],
            env: 'LISK_NETWORK',
            arg: '--network,-n',
        },
        CUSTOM_CONFIG_FILE: {
            type: ['string', 'null'],
            description: 'Custom configuration file path',
            default: null,
            env: 'LISK_CONFIG_FILE',
            arg: '--config,-c',
        },
    },
    default: {
        NETWORK: 'devnet',
        CUSTOM_CONFIG_FILE: null,
    },
};
lisk_sdk_1.configurator.registerSchema(appSchema);
const appConfig = {
    version: packageJSON.version,
    protocolVersion: packageJSON.lisk.protocolVersion,
    lastCommitId,
    buildVersion,
};
if (process.env.NODE_ENV === 'test' && process.env.PROTOCOL_VERSION) {
    appConfig.protocolVersion = process.env.PROTOCOL_VERSION;
}
lisk_sdk_1.configurator.loadConfig(appConfig);
const { NETWORK, CUSTOM_CONFIG_FILE } = lisk_sdk_1.configurator.getConfig();
process.env.LISK_NETWORK = NETWORK;
lisk_sdk_1.configurator.loadConfigFile(path_1.default.resolve(__dirname, `../../config/${NETWORK}/config`));
if (CUSTOM_CONFIG_FILE) {
    lisk_sdk_1.configurator.loadConfigFile(path_1.default.resolve(CUSTOM_CONFIG_FILE));
}
const config = lisk_sdk_1.configurator.getConfig();
exports.config = config;
config.label = `lisk-${NETWORK}-${config.modules.http_api.httpPort}`;
//# sourceMappingURL=config.js.map