/// <reference types="node" />
import { BaseTransaction, TransactionJSON, TransactionResponse } from '@liskhq/lisk-transactions';
import { DataAccess } from './data_access';
import { Slots } from './slots';
import { StateStore } from './state_store';
import { BlockHeader, BlockHeaderJSON, BlockInstance, BlockJSON, Contexter, Storage, StorageTransaction } from './types';
interface ChainConstructor {
    readonly storage: Storage;
    readonly genesisBlock: BlockJSON;
    readonly slots: Slots;
    readonly registeredTransactions: {
        readonly [key: number]: typeof BaseTransaction;
    };
    readonly epochTime: string;
    readonly blockTime: number;
    readonly networkIdentifier: string;
    readonly maxPayloadLength: number;
    readonly rewardDistance: number;
    readonly rewardOffset: number;
    readonly rewardMilestones: ReadonlyArray<string>;
    readonly totalAmount: string;
    readonly stateBlockSize?: number;
    readonly minBlockHeaderCache?: number;
    readonly maxBlockHeaderCache?: number;
}
export declare class Chain {
    readonly dataAccess: DataAccess;
    readonly slots: Slots;
    readonly blockReward: {
        readonly calculateMilestone: (height: number) => number;
        readonly calculateReward: (height: number) => bigint;
        readonly calculateSupply: (height: number) => bigint;
    };
    private _lastBlock;
    private readonly blocksVerify;
    private readonly storage;
    private readonly _networkIdentifier;
    private readonly blockRewardArgs;
    private readonly genesisBlock;
    private readonly constants;
    private readonly events;
    constructor({ storage, genesisBlock, registeredTransactions, epochTime, blockTime, networkIdentifier, maxPayloadLength, rewardDistance, rewardOffset, rewardMilestones, totalAmount, stateBlockSize, minBlockHeaderCache, maxBlockHeaderCache, }: ChainConstructor);
    get lastBlock(): BlockInstance;
    deserialize(blockJSON: BlockJSON): BlockInstance;
    serialize(blockJSON: BlockInstance): BlockJSON;
    serializeBlockHeader(blockHeader: BlockHeader): BlockHeaderJSON;
    deserializeBlockHeader(blockJSON: BlockHeaderJSON): BlockHeader;
    deserializeTransaction(transactionJSON: TransactionJSON): BaseTransaction;
    init(): Promise<void>;
    resetBlockHeaderCache(): void;
    newStateStore(skipLastHeights?: number): Promise<StateStore>;
    private _cacheBlockHeaders;
    validateBlockHeader(block: BlockInstance, blockBytes: Buffer): void;
    resetState(): Promise<void>;
    verify(blockInstance: BlockInstance, _: StateStore, { skipExistingCheck }: {
        readonly skipExistingCheck: boolean;
    }): Promise<void>;
    apply(blockInstance: BlockInstance, stateStore: StateStore): Promise<void>;
    applyGenesis(blockInstance: BlockInstance, stateStore: StateStore): Promise<void>;
    save(blockInstance: BlockInstance, stateStore: StateStore, { saveOnlyState, removeFromTempTable }?: {
        saveOnlyState: boolean;
        removeFromTempTable: boolean;
    }): Promise<void>;
    undo(blockInstance: BlockInstance, stateStore: StateStore): Promise<void>;
    private _deleteLastBlock;
    remove(block: BlockInstance, stateStore: StateStore, { saveTempBlock }?: {
        saveTempBlock: boolean;
    }): Promise<void>;
    removeBlockFromTempTable(blockId: string, tx: StorageTransaction): Promise<void>;
    exists(block: BlockInstance): Promise<boolean>;
    getHighestCommonBlock(ids: string[]): Promise<BlockHeader | undefined>;
    filterReadyTransactions(transactions: BaseTransaction[], context: Contexter): Promise<BaseTransaction[]>;
    validateTransactions(transactions: BaseTransaction[]): Promise<ReadonlyArray<TransactionResponse>>;
    applyTransactions(transactions: BaseTransaction[]): Promise<ReadonlyArray<TransactionResponse>>;
    applyTransactionsWithStateStore(transactions: BaseTransaction[], stateStore: StateStore): Promise<ReadonlyArray<TransactionResponse>>;
    getTotalEarningAndBurnt(blockInstance: BlockInstance): {
        readonly totalEarning: bigint;
        readonly totalBurnt: bigint;
    };
}
export {};
