"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Storage {
    constructor(storage) {
        this._storage = storage;
    }
    async getBlockHeaderByID(id) {
        const [block] = await this._storage.entities.Block.get({ id });
        return block;
    }
    async getBlockHeadersByIDs(arrayOfBlockIds) {
        const blocks = await this._storage.entities.Block.get({ id_in: arrayOfBlockIds }, { limit: arrayOfBlockIds.length });
        return blocks;
    }
    async getBlockHeaderByHeight(height) {
        const [block] = await this._storage.entities.Block.get({ height });
        return block;
    }
    async getBlockHeadersByHeightBetween(fromHeight, toHeight) {
        const blocks = await this._storage.entities.Block.get({ height_gte: fromHeight, height_lte: toHeight }, { limit: null, sort: 'height:desc' });
        return blocks;
    }
    async getBlockHeadersWithHeights(heightList) {
        const blocks = await this._storage.entities.Block.get({
            height_in: heightList,
        }, {
            sort: 'height:asc',
            limit: heightList.length,
        });
        return blocks;
    }
    async getLastBlockHeader() {
        const [lastBlockHeader] = await this._storage.entities.Block.get({}, { limit: 1, sort: 'height:desc' });
        return lastBlockHeader;
    }
    async getLastCommonBlockHeader(arrayOfBlockIds) {
        const [block] = await this._storage.entities.Block.get({
            id_in: arrayOfBlockIds,
        }, { sort: 'height:desc', limit: 1 });
        return block;
    }
    async getBlocksCount() {
        const count = await this._storage.entities.Block.count({}, {});
        return count;
    }
    async getBlockByID(id) {
        const [block] = await this._storage.entities.Block.get({ id }, { extended: true });
        return block;
    }
    async getBlocksByIDs(arrayOfBlockIds) {
        const blocks = await this._storage.entities.Block.get({ id_in: arrayOfBlockIds }, { extended: true });
        return blocks;
    }
    async getBlockByHeight(height) {
        const [block] = await this._storage.entities.Block.get({ height }, { extended: true });
        return block;
    }
    async getBlocksByHeightBetween(fromHeight, toHeight) {
        const blocks = await this._storage.entities.Block.get({ height_gte: fromHeight, height_lte: toHeight }, { extended: true, limit: null, sort: 'height:desc' });
        return blocks;
    }
    async getLastBlock() {
        const [lastBlock] = await this._storage.entities.Block.get({}, { sort: 'height:desc', limit: 1, extended: true });
        return lastBlock;
    }
    async getTempBlocks() {
        const tempBlocks = await this._storage.entities.TempBlock.get({}, { sort: 'height:asc', limit: null });
        return tempBlocks;
    }
    async isTempBlockEmpty() {
        const isEmpty = await this._storage.entities.TempBlock.isEmpty();
        return isEmpty;
    }
    clearTempBlocks() {
        this._storage.entities.TempBlock.truncate();
    }
    async deleteBlocksWithHeightGreaterThan(height) {
        await this._storage.entities.Block.delete({
            height_gt: height,
        });
    }
    async isBlockPersisted(blockId) {
        const isPersisted = await this._storage.entities.Block.isPersisted({
            blockId,
        });
        return isPersisted;
    }
    async getChainState(key) {
        const value = await this._storage.entities.ChainState.getKey(key);
        return value;
    }
    async getConsensusState(key) {
        const value = await this._storage.entities.ConsensusState.getKey(key);
        return value;
    }
    async getAccountsByPublicKey(arrayOfPublicKeys) {
        const accounts = await this._storage.entities.Account.get({ publicKey_in: arrayOfPublicKeys }, { limit: arrayOfPublicKeys.length });
        return accounts;
    }
    async getAccountByAddress(address) {
        const account = await this._storage.entities.Account.getOne({ address }, { limit: 1 });
        return account;
    }
    async getAccountsByAddress(arrayOfAddresses) {
        const accounts = await this._storage.entities.Account.get({ address_in: arrayOfAddresses }, { limit: arrayOfAddresses.length });
        return accounts;
    }
    async getDelegates() {
        const accounts = await this._storage.entities.Account.get({ isDelegate: true }, { limit: null, sort: ['totalVotesReceived:desc'] });
        return accounts;
    }
    async resetAccountMemTables() {
        await this._storage.entities.Account.resetMemTables();
    }
    async getTransactionsByIDs(arrayOfTransactionIds) {
        const transactions = await this._storage.entities.Transaction.get({
            id_in: arrayOfTransactionIds,
        }, { limit: arrayOfTransactionIds.length });
        return transactions;
    }
    async isTransactionPersisted(transactionId) {
        const isPersisted = await this._storage.entities.Transaction.isPersisted({
            id: transactionId,
        });
        return isPersisted;
    }
}
exports.Storage = Storage;
//# sourceMappingURL=storage.js.map