"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cloneDeep = require("lodash.clonedeep");
const isEqual = require("lodash.isequal");
const account_1 = require("../account");
const utils_1 = require("../utils");
class AccountStore {
    constructor(accountEntity) {
        this._updatedKeys = {};
        this._originalUpdatedKeys = {};
        this._primaryKey = 'address';
        this._name = 'Account';
        this._account = accountEntity;
        this._data = [];
        this._updatedKeys = {};
        this._primaryKey = 'address';
        this._name = 'Account';
        this._originalData = [];
        this._originalUpdatedKeys = {};
    }
    async cache(filter) {
        const result = await this._account.get(filter, { limit: null });
        const resultAccountObjects = result.map(accountJSON => new account_1.Account(accountJSON));
        this._data = utils_1.uniqBy([...this._data, ...resultAccountObjects], this._primaryKey);
        return resultAccountObjects;
    }
    createSnapshot() {
        this._originalData = cloneDeep(this._data);
        this._updatedKeys = cloneDeep(this._updatedKeys);
    }
    restoreSnapshot() {
        this._data = this._originalData;
        this._updatedKeys = this._originalUpdatedKeys;
        this._originalData = [];
        this._originalUpdatedKeys = {};
    }
    async get(primaryValue) {
        const element = this._data.find(item => item[this._primaryKey] === primaryValue);
        if (element) {
            return new account_1.Account(element.toJSON());
        }
        const [elementFromDB] = await this._account.get({ [this._primaryKey]: primaryValue }, { limit: null });
        if (elementFromDB) {
            this._data.push(new account_1.Account(elementFromDB));
            return new account_1.Account(elementFromDB);
        }
        throw new Error(`${this._name} with ${this._primaryKey} = ${primaryValue} does not exist`);
    }
    async getOrDefault(primaryValue) {
        const element = this._data.find(item => item[this._primaryKey] === primaryValue);
        if (element) {
            return new account_1.Account(element.toJSON());
        }
        const [elementFromDB] = await this._account.get({ [this._primaryKey]: primaryValue }, { limit: null });
        if (elementFromDB) {
            this._data.push(new account_1.Account(elementFromDB));
            return new account_1.Account(elementFromDB);
        }
        const defaultElement = account_1.Account.getDefaultAccount(primaryValue);
        const newElementIndex = this._data.push(defaultElement) - 1;
        this._updatedKeys[newElementIndex] = Object.keys(defaultElement);
        return new account_1.Account(defaultElement.toJSON());
    }
    getUpdated() {
        return [...this._data];
    }
    find(fn) {
        const foundAccount = this._data.find(fn);
        if (!foundAccount) {
            return undefined;
        }
        return new account_1.Account(foundAccount.toJSON());
    }
    set(primaryValue, updatedElement) {
        const elementIndex = this._data.findIndex(item => item[this._primaryKey] === primaryValue);
        if (elementIndex === -1) {
            throw new Error(`${this._name} with ${this._primaryKey} = ${primaryValue} does not exist`);
        }
        const updatedKeys = Object.entries(updatedElement).reduce((existingUpdatedKeys, [key, value]) => {
            const account = this._data[elementIndex];
            if (!isEqual(value, account[key])) {
                existingUpdatedKeys.push(key);
            }
            return existingUpdatedKeys;
        }, []);
        this._data[elementIndex] = updatedElement;
        this._updatedKeys[elementIndex] = this._updatedKeys[elementIndex]
            ? [...new Set([...this._updatedKeys[elementIndex], ...updatedKeys])]
            : updatedKeys;
    }
    async finalize(tx) {
        const affectedAccounts = Object.entries(this._updatedKeys).map(([index, updatedKeys]) => ({
            updatedItem: this._data[parseInt(index, 10)].toJSON(),
            updatedKeys,
        }));
        const updateToAccounts = affectedAccounts.map(async ({ updatedItem, updatedKeys }) => {
            const filter = { [this._primaryKey]: updatedItem[this._primaryKey] };
            const updatedData = updatedKeys.reduce((data, key) => {
                data[key] = updatedItem[key];
                return data;
            }, {});
            return this._account.upsert(filter, updatedData, null, tx);
        });
        await Promise.all(updateToAccounts);
    }
}
exports.AccountStore = AccountStore;
//# sourceMappingURL=account_store.js.map