"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class ConsensusStateStore {
    constructor(consensusStateEntity, additionalInformation) {
        this._name = 'ConsensusState';
        this._consensusState = consensusStateEntity;
        this._lastBlockHeaders = additionalInformation.lastBlockHeaders;
        this._data = {};
        this._originalData = {};
        this._updatedKeys = new Set();
        this._originalUpdatedKeys = new Set();
    }
    get lastBlockHeaders() {
        return this._lastBlockHeaders;
    }
    async cache() {
        const results = await this._consensusState.get();
        for (const { key, value } of results) {
            this._data[key] = value;
        }
    }
    createSnapshot() {
        this._originalData = { ...this._data };
        this._originalUpdatedKeys = new Set(this._updatedKeys);
    }
    restoreSnapshot() {
        this._data = { ...this._originalData };
        this._updatedKeys = new Set(this._originalUpdatedKeys);
    }
    async get(key) {
        const value = this._data[key];
        if (value) {
            return value;
        }
        const dbValue = await this._consensusState.getKey(key);
        if (dbValue === undefined) {
            return dbValue;
        }
        this._data[key] = dbValue;
        return this._data[key];
    }
    getOrDefault() {
        throw new Error(`getOrDefault cannot be called for ${this._name}`);
    }
    find() {
        throw new Error(`getOrDefault cannot be called for ${this._name}`);
    }
    set(key, value) {
        this._data[key] = value;
        this._updatedKeys.add(key);
    }
    async finalize(tx) {
        if (this._updatedKeys.size === 0) {
            return;
        }
        await Promise.all(Array.from(this._updatedKeys).map(key => this._consensusState.setKey(key, this._data[key], tx)));
    }
}
exports.ConsensusStateStore = ConsensusStateStore;
//# sourceMappingURL=consensus_state_store.js.map