/// <reference types="node" />
import { EventEmitter } from 'events';
import { Rounds } from './rounds';
import { Block, BlockHeader, Chain, DPoSProcessingOptions, StateStore } from './types';
interface DposConstructor {
    readonly chain: Chain;
    readonly activeDelegates?: number;
    readonly standbyDelegates?: number;
    readonly standbyThreshold?: bigint;
    readonly voteWeightCapRate?: number;
    readonly delegateListRoundOffset?: number;
}
export declare class Dpos {
    readonly rounds: Rounds;
    readonly events: EventEmitter;
    private readonly delegateListRoundOffset;
    private readonly delegateActiveRoundLimit;
    private readonly delegatesList;
    private readonly delegatesInfo;
    private readonly chain;
    private readonly _delegatesPerRound;
    private readonly _activeDelegates;
    constructor({ chain, activeDelegates, standbyDelegates, standbyThreshold, delegateListRoundOffset, voteWeightCapRate, }: DposConstructor);
    get delegatesPerRound(): number;
    getForgerAddressesForRound(round: number): Promise<ReadonlyArray<string>>;
    onBlockFinalized(stateStore: StateStore, finalizedHeight: number): Promise<void>;
    getMinActiveHeight(height: number, address: string, stateStore: StateStore, delegateActiveRoundLimit?: number): Promise<number>;
    isActiveDelegate(address: string, height: number): Promise<boolean>;
    isStandbyDelegate(address: string, height: number, stateStore: StateStore): Promise<boolean>;
    private _findEarliestActiveListRound;
    verifyBlockForger(block: BlockHeader): Promise<boolean>;
    apply(block: Block, stateStore: StateStore, { delegateListRoundOffset }?: DPoSProcessingOptions): Promise<boolean>;
    undo(block: Block, stateStore: StateStore, { delegateListRoundOffset }?: DPoSProcessingOptions): Promise<boolean>;
    isDPoSProtocolCompliant(blockHeader: BlockHeader, store: StateStore): Promise<boolean>;
}
export {};
