"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_cryptography_1 = require("@liskhq/lisk-cryptography");
const SIZE_INT32 = 4;
const SIZE_INT64 = 8;
exports.getBlockBytes = (block) => {
    const blockVersionBuffer = lisk_cryptography_1.intToBuffer(block.version, SIZE_INT32, lisk_cryptography_1.LITTLE_ENDIAN);
    const timestampBuffer = lisk_cryptography_1.intToBuffer(block.timestamp, SIZE_INT32, lisk_cryptography_1.LITTLE_ENDIAN);
    const previousBlockBuffer = block.previousBlockId
        ? lisk_cryptography_1.intToBuffer(block.previousBlockId, SIZE_INT64, lisk_cryptography_1.BIG_ENDIAN)
        : Buffer.alloc(SIZE_INT64);
    const seedRevealBuffer = Buffer.from(block.seedReveal, 'hex');
    const heightBuffer = lisk_cryptography_1.intToBuffer(block.height, SIZE_INT32, lisk_cryptography_1.LITTLE_ENDIAN);
    const maxHeightPreviouslyForgedBuffer = lisk_cryptography_1.intToBuffer(block.maxHeightPreviouslyForged, SIZE_INT32, lisk_cryptography_1.LITTLE_ENDIAN);
    const maxHeightPrevotedBuffer = lisk_cryptography_1.intToBuffer(block.maxHeightPrevoted, SIZE_INT32, lisk_cryptography_1.LITTLE_ENDIAN);
    const numTransactionsBuffer = lisk_cryptography_1.intToBuffer(block.numberOfTransactions, SIZE_INT32, lisk_cryptography_1.LITTLE_ENDIAN);
    const totalAmountBuffer = lisk_cryptography_1.intToBuffer(block.totalAmount.toString(), SIZE_INT64, lisk_cryptography_1.LITTLE_ENDIAN);
    const totalFeeBuffer = lisk_cryptography_1.intToBuffer(block.totalFee.toString(), SIZE_INT64, lisk_cryptography_1.LITTLE_ENDIAN);
    const rewardBuffer = lisk_cryptography_1.intToBuffer(block.reward.toString(), SIZE_INT64, lisk_cryptography_1.LITTLE_ENDIAN);
    const payloadLengthBuffer = lisk_cryptography_1.intToBuffer(block.payloadLength, SIZE_INT32, lisk_cryptography_1.LITTLE_ENDIAN);
    const payloadHashBuffer = lisk_cryptography_1.hexToBuffer(block.payloadHash);
    const generatorPublicKeyBuffer = lisk_cryptography_1.hexToBuffer(block.generatorPublicKey);
    return Buffer.concat([
        blockVersionBuffer,
        timestampBuffer,
        previousBlockBuffer,
        seedRevealBuffer,
        heightBuffer,
        maxHeightPreviouslyForgedBuffer,
        maxHeightPrevotedBuffer,
        numTransactionsBuffer,
        totalAmountBuffer,
        totalFeeBuffer,
        rewardBuffer,
        payloadLengthBuffer,
        payloadHashBuffer,
        generatorPublicKeyBuffer,
    ]);
};
exports.getBlockBytesWithSignature = (block) => {
    const blockBuffer = exports.getBlockBytes(block);
    const blockSignatureBuffer = block.blockSignature
        ? lisk_cryptography_1.hexToBuffer(block.blockSignature)
        : Buffer.alloc(0);
    return Buffer.concat([blockBuffer, blockSignatureBuffer]);
};
//# sourceMappingURL=get_block_bytes.js.map