"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Ajv = require("ajv");
const formats = require("./formats");
class LiskValidator {
    constructor() {
        this.validator = new Ajv({
            allErrors: true,
            schemaId: 'auto',
            useDefaults: false,
        });
        for (const formatName of Object.keys(formats)) {
            this.validator.addFormat(formatName, formats[formatName]);
        }
        this.validator.addKeyword('uniqueSignedPublicKeys', {
            type: 'array',
            compile: () => (data) => new Set(data
                .filter(datum => typeof datum === 'string')
                .map((key) => key.slice(1))).size === data.length,
        });
    }
    validate(schema, data) {
        if (!this.validator.validate(schema, data)) {
            return this.validator.errors;
        }
        return [];
    }
}
exports.validator = new LiskValidator();
//# sourceMappingURL=lisk_validator.js.map