/// <reference types="node" />
import { TransactionError } from './errors';
import { Status } from './response';
import { Account, BlockHeader, TransactionJSON } from './transaction_types';
export interface TransactionResponse {
    readonly id: string;
    readonly status: Status;
    readonly errors: ReadonlyArray<TransactionError>;
}
export interface StateStorePrepare {
    readonly account: {
        cache(filterArray: ReadonlyArray<{
            readonly [key: string]: string;
        }>): Promise<ReadonlyArray<Account>>;
    };
}
export interface AccountState {
    cache(filterArray: ReadonlyArray<{
        readonly [key: string]: string;
    }>): Promise<ReadonlyArray<Account>>;
    get(key: string): Promise<Account>;
    getOrDefault(key: string): Promise<Account>;
    find(func: (item: Account) => boolean): Account | undefined;
    set(key: string, value: Account): void;
}
export interface ChainState {
    readonly lastBlockHeader: BlockHeader;
    readonly lastBlockReward: bigint;
    readonly networkIdentifier: string;
}
export interface StateStore {
    readonly account: AccountState;
    readonly chain: ChainState;
}
export declare const ENTITY_ACCOUNT = "account";
export declare const ENTITY_TRANSACTION = "transaction";
export declare abstract class BaseTransaction {
    readonly blockId?: string;
    readonly height?: number;
    readonly confirmations?: number;
    readonly type: number;
    readonly asset: object;
    nonce: bigint;
    fee: bigint;
    receivedAt?: Date;
    senderPublicKey: string;
    signatures: string[];
    static TYPE: number;
    static MIN_REMAINING_BALANCE: bigint;
    static MIN_FEE_PER_BYTE: number;
    static NAME_FEE: bigint;
    protected _id?: string;
    protected _minFee?: bigint;
    protected abstract validateAsset(): ReadonlyArray<TransactionError>;
    protected abstract applyAsset(store: StateStore): Promise<ReadonlyArray<TransactionError>>;
    protected abstract undoAsset(store: StateStore): Promise<ReadonlyArray<TransactionError>>;
    constructor(rawTransaction: unknown);
    get id(): string;
    get minFee(): bigint;
    get senderId(): string;
    toJSON(): TransactionJSON;
    stringify(): string;
    getBytes(): Buffer;
    validate(): TransactionResponse;
    apply(store: StateStore): Promise<TransactionResponse>;
    undo(store: StateStore): Promise<TransactionResponse>;
    prepare(store: StateStorePrepare): Promise<void>;
    verifySignatures(store: StateStore): Promise<TransactionResponse>;
    sign(networkIdentifier: string, senderPassphrase?: string, passphrases?: ReadonlyArray<string>, keys?: {
        readonly mandatoryKeys: Array<Readonly<string>>;
        readonly optionalKeys: Array<Readonly<string>>;
    }): void;
    getBasicBytes(): Buffer;
    assetToJSON(): object;
    protected assetToBytes(): Buffer;
    private _validateSchema;
}
