/// <reference types="node" />
import { DelegateTransaction } from './10_delegate_transaction';
import { MultisignatureTransaction } from './12_multisignature_transaction';
import { VoteTransaction } from './13_vote_transaction';
import { UnlockTransaction } from './14_unlock_transaction';
import { ProofOfMisbehaviorTransaction } from './15_proof_of_misbehavior_transaction';
import { TransferTransaction } from './8_transfer_transaction';
import { BaseTransaction, StateStore, StateStorePrepare } from './base_transaction';
import { castVotes } from './cast_votes';
import * as constants from './constants';
import { convertToAssetError, convertToTransactionError, TransactionError } from './errors';
import { registerDelegate } from './register_delegate';
import { registerMultisignature } from './register_multisignature_account';
import { reportMisbehavior } from './report_misbehavior';
import { createResponse, Status, TransactionResponse } from './response';
import { transactionInterface } from './schema';
import { signMultiSignatureTransaction } from './sign_multi_signature_transaction';
import { Account, TransactionJSON } from './transaction_types';
import { transfer } from './transfer';
import { unlockToken } from './unlock_token';
declare const exposedUtils: {
    convertBeddowsToLSK: (beddowsAmount?: string | undefined) => string;
    getId: (transactionBytes: Buffer) => string;
    convertLSKToBeddows: (lskAmount?: string | undefined) => string;
    prependMinusToPublicKeys: (publicKeys: readonly string[]) => readonly string[];
    prependPlusToPublicKeys: (publicKeys: readonly string[]) => readonly string[];
    validateMultisignatures: (publicKeys: readonly string[], signatures: readonly string[], minimumValidations: number, transactionBytes: Buffer, id?: string | undefined) => import("./transaction_types").IsValidResponse;
    validateSignature: (publicKey: string, signature: string, bytes: Buffer, id?: string | undefined) => import("./transaction_types").IsValidResponseWithError;
    verifyMinRemainingBalance: (id: string, account: Account, minRemainingBalance: bigint) => TransactionError | undefined;
    validateSenderIdAndPublicKey: (id: string, senderId: string, senderPublicKey: string) => TransactionError | undefined;
    verifyMultiSignatureTransaction: (id: string, sender: Account, signatures: readonly string[], transactionBytes: Buffer) => TransactionError[];
    verifySenderPublicKey: (id: string, sender: Account, publicKey: string) => TransactionError | undefined;
};
export { Account, BaseTransaction, StateStore, StateStorePrepare, TransferTransaction, transfer, DelegateTransaction, registerDelegate, VoteTransaction, castVotes, MultisignatureTransaction, UnlockTransaction, unlockToken, reportMisbehavior, createResponse, ProofOfMisbehaviorTransaction, registerMultisignature, signMultiSignatureTransaction, Status, TransactionResponse, TransactionJSON, TransactionError, transactionInterface, convertToAssetError, convertToTransactionError, constants, exposedUtils as utils, };
