"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_validator_1 = require("@liskhq/lisk-validator");
const constants_1 = require("../constants");
const LISK_MAX_DECIMAL_POINTS = 8;
const getDecimalPlaces = (amount) => (amount.split('.')[1] || '').length;
exports.convertBeddowsToLSK = (beddowsAmount) => {
    if (typeof beddowsAmount !== 'string') {
        throw new Error('Cannot convert non-string amount');
    }
    if (getDecimalPlaces(beddowsAmount)) {
        throw new Error('Beddows amount should not have decimal points');
    }
    const beddowsAmountBigInt = BigInt(beddowsAmount);
    if (lisk_validator_1.isGreaterThanMaxUInt64(beddowsAmountBigInt)) {
        throw new Error('Beddows amount out of range');
    }
    const int = (beddowsAmountBigInt / BigInt(constants_1.FIXED_POINT)).toString();
    const floating = Number(beddowsAmountBigInt % BigInt(constants_1.FIXED_POINT)) / constants_1.FIXED_POINT;
    const floatingPointsSplit = floating
        .toLocaleString('en-US', {
        maximumFractionDigits: LISK_MAX_DECIMAL_POINTS,
    })
        .split('.')[1];
    const res = floating !== 0 ? `${int}.${floatingPointsSplit}` : int;
    return res;
};
exports.convertLSKToBeddows = (lskAmount) => {
    var _a;
    if (typeof lskAmount !== 'string') {
        throw new Error('Cannot convert non-string amount');
    }
    if (getDecimalPlaces(lskAmount) > LISK_MAX_DECIMAL_POINTS) {
        throw new Error('LSK amount has too many decimal points');
    }
    const splitAmount = lskAmount.split('.');
    const liskAmountInt = BigInt(splitAmount[0]);
    const liskAmountFloatBigInt = BigInt(((_a = splitAmount[1]) !== null && _a !== void 0 ? _a : '0').padEnd(LISK_MAX_DECIMAL_POINTS, '0'));
    const beddowsAmountBigInt = liskAmountInt * BigInt(constants_1.FIXED_POINT) + liskAmountFloatBigInt;
    if (lisk_validator_1.isGreaterThanMaxUInt64(beddowsAmountBigInt)) {
        throw new Error('LSK amount out of range');
    }
    return beddowsAmountBigInt.toString();
};
exports.prependPlusToPublicKeys = (publicKeys) => publicKeys.map(publicKey => `+${publicKey}`);
exports.prependMinusToPublicKeys = (publicKeys) => publicKeys.map(publicKey => `-${publicKey}`);
//# sourceMappingURL=format.js.map